@@ -474,11 +474,18 @@ def writeIMAGCDF(datastream, filename, **kwargs):
     proj = headers.get('DataLocationReference','')
     longi = headers.get('DataAcquisitionLongitude','')
     lati = headers.get('DataAcquisitionLatitude','')
+    ele = headers.get('DataElevation','')
     try:
         longi = "{:.3f}".format(float(longi))
         lati = "{:.3f}".format(float(lati))
     except:
         print("writeIMAGCDF: could not convert lat long to floats")
+    try:
+        ele = "{:.3f}".format(float(ele))
+    except:
+        print("writeIMAGCDF: could not convert elevation to float")
+    if not ele=='':
+        globalAttrs['Elevation'] = { 0 : float(ele) }
     if not longi=='' or lati=='':
         if proj == '':
             patt = mycdf.attrs
@@ -503,7 +510,8 @@ def writeIMAGCDF(datastream, filename, **kwargs):
         globalAttrs['IagaCode'] = { 0 : headers.get('StationID','')}
 
 
-    mycdf.write_globalattrs(globalAttrs)    
+    # writing of global attributes after checking for independency of eventually provided F (S) record - line 595
+    #mycdf.write_globalattrs(globalAttrs)    
 
     ### #########################################
     ###               Data 
@@ -576,6 +584,16 @@ def writeIMAGCDF(datastream, filename, **kwargs):
             #keep column and (later) leave time       
             useScalarTimes=True  # change to False in order to use a single col
         """
+
+    ## Update DataComponents/Elements records regarding S (independent) or F (vector)
+    comps = datastream.header.get('DataComponents')
+    if len(comps) == 4 and 'f' in keylst:
+        comps = comps[:3] + fcolname
+        globalAttrs['ElementsRecorded'] = { 0 : comps}
+        
+    ## writing Global header data
+    mycdf.write_globalattrs(globalAttrs)
+
     ## get sampling rate of vec, get sampling rate of scalar, if different extract scalar and time use separate, else ..
 
     for key in keylst:
@@ -708,7 +726,6 @@ def writeIMAGCDF(datastream, filename, **kwargs):
 
     success = filename
 
-
     if len(flaglist) > 0 and addflags == True:
         flagstart = 'FlagBeginTimes'
         flagend = 'FlagEndTimes'
