@@ -81,6 +81,7 @@ from magpy.lib.format_gfztmp import *
 from magpy.lib.format_neic import *
 from magpy.lib.format_rcs import *
 from magpy.lib.format_pha import *
+from magpy.lib.format_predstorm import *
 from magpy.lib.format_basiccsv import *
 
 from magpy.lib.format_imf import *
@@ -271,6 +272,9 @@ def isFormat(filename, format_type):
     elif (format_type == "PHA"): # Potentially Hazardous Objects (This research has made use of data and/or services provided by the International Astronomical Union's Minor Planet Center.)
         if (isPHA(filename)):
             return True
+    elif (format_type == "PREDSTORM"): # PREDSTORM space weather data
+        if (isPREDSTORM(filename)):
+            return True
     elif (format_type == "USBLOG"): # Data from the USB temperature logger
         if (isUSBLOG(filename)):
             return True
@@ -401,6 +405,8 @@ def readFormat(filename, format_type, headonly=False, **kwargs):
         return readNEIC(filename, headonly, **kwargs)
     elif (format_type == "PHA"):
         return readPHA(filename, headonly, **kwargs)
+    elif (format_type == "PREDSTORM"):
+        return readPREDSTORM(filename, headonly, **kwargs)
     elif (format_type == "CSV"):
         return readCSV(filename, headonly, **kwargs)
     else:
